@@ -7,7 +7,6 @@ import signal
 import socket
 import threading
 import traceback
-import webbrowser
 from pathlib import Path
 
 from packaging.version import parse as vparse
@@ -23,10 +22,12 @@ from lyrebird.mock.handlers.encoder_decoder_handler import EncoderDecoder
 from lyrebird.mock.mock_server import LyrebirdMockServer
 from lyrebird.notice_center import NoticeCenter
 from lyrebird.plugins import PluginManager
-from lyrebird.proxy.proxy_server import LyrebirdProxyServer
+from lyrebird.mitm.proxy_server import LyrebirdProxyServer
 from lyrebird.task import BackgroundTaskServer
+from lyrebird.base_server import MultiProcessServerMessageDispatcher
 from lyrebird import utils
 
+
 logger = log.get_logger()
 
 
@@ -67,7 +68,7 @@ def main():
                         help='Set extra mock server port, default port is 9999')
     parser.add_argument('--proxy', dest='proxy', type=int, help='Set proxy server port, default port is 4272')
     parser.add_argument('--data', dest='data', help='Set data dir, default is "./data/"')
-    parser.add_argument('-b', '--no_browser', dest='no_browser',
+    parser.add_argument('-b', '--no-browser', dest='no_browser',
                         action='store_true', help='Start without open a browser')
     parser.add_argument('-c', '--config', action='append', dest='config',
                         help='Start with a config file. Default is "~/.lyrebird/conf.json"')
@@ -76,6 +77,7 @@ def main():
     parser.add_argument('--plugin', action='append', help='Set a plugin project path')
     parser.add_argument('--database', dest='database', help='Set a database path. Default is "~/.lyrebird/lyrebird.db"')
     parser.add_argument('--es', dest='extra_string', action='append', nargs=2, help='Set a custom config')
+    parser.add_argument('--no-mitm', dest='no_mitm', action='store_true', help='Start without mitmproxy on 4272')
 
     subparser = parser.add_subparsers(dest='sub_command')
 
@@ -96,7 +98,7 @@ def main():
     # init logger for main process
     application._cm.config['verbose'] = args.verbose
     application._cm.config['log'] = args.log
-    log.init()
+    log.init(application._cm.config)
 
     # Add exception hook
     def process_excepthook(exc_type, exc_value, tb):
@@ -168,16 +170,36 @@ def run(args: argparse.Namespace):
 
     # Main server
     application.server['event'] = EventServer()
-
+    # mutilprocess message dispatcher
+    application.server['dispather'] = MultiProcessServerMessageDispatcher()
     application.server['task'] = BackgroundTaskServer()
-    application.server['proxy'] = LyrebirdProxyServer()
-    application.server['mock'] = LyrebirdMockServer()
+
+    # Start mitmproxy server
+    # if set --no-mitm in commandline , skip start proxy server
+    # if set proxy.no_mitm in config file, skip start proxy server
+    conf_no_mitm = application._cm.config.get('proxy.no_mitm', False)
+    args_no_mitm = args.no_mitm
+    if args_no_mitm:
+        should_start_mitm = not args_no_mitm
+    else:
+        should_start_mitm = not conf_no_mitm
+    if should_start_mitm:
+        application.status_checkpoints['mitm_proxy'] = False
+        application.server['proxy'] = LyrebirdProxyServer()
+
     application.server['extra.mock'] = ExtraMockServer()
     application.server['db'] = LyrebirdDatabaseServer(path=args.database)
     application.server['plugin'] = PluginManager()
     application.server['checker'] = LyrebirdCheckerServer()
 
-    application.start_server()
+    # Mock mush init after other servers
+    application.server['mock'] = LyrebirdMockServer()
+
+    # handle progress message
+    application.process_status_listener()
+
+    # Start server without mock server, mock server must start after all blueprint is done
+    application.start_server_without_mock()
 
     # int statistics reporter
     application.reporter = reporter.Reporter()
@@ -202,12 +224,14 @@ def run(args: argparse.Namespace):
     if args.script:
         application.server['checker'].load_scripts(args.script)
 
-    # auto open web browser
-    if not args.no_browser:
-        webbrowser.open(f'http://localhost:{application.config["mock.port"]}')
+    # Start server without mock server, mock server must start after all blueprint is done
+    application.start_mock_server()
 
-    # Lyrebird status contains: 'READY' and 'INITING'
-    application.status = 'READY'
+    # auto open web browser
+    application.NO_BROSWER = args.no_browser
+
+    # main process is ready, publish system event
+    application.status_ready()
 
     # stop event handler
     def signal_handler(signum, frame):
