@@ -4,6 +4,7 @@ import json
 import time
 import codecs
 import shutil
+import traceback
 from pathlib import Path
 from urllib.parse import urlparse
 from collections import OrderedDict
@@ -80,13 +81,31 @@ class DataManager:
         self.add_super_by()
 
     def add_parent_into_node(self):
-        for node in self.id_map.values():
-            node.update({
-                'parent': self._get_abs_parent_obj(node),
-                'abs_parent_path': self._get_abs_parent_path(node)
-            })
+        self.add_parent(self.root)
         self.unsave_keys.update(['parent', 'abs_parent_path'])
 
+    def add_parent(self, node, parent_node=None):
+        parent_node_parent = parent_node['parent'] if parent_node and parent_node.get('parent') else []
+        parent_obj = parent_node_parent + [{
+            'id': node['id'],
+            'name': node['name'],
+            'type': node['type'],
+            'parent_id': node['parent_id']
+        }]
+
+        abs_parent_path = f"{parent_node['abs_parent_path']}{node['name']}/" if parent_node else '/'
+
+        node.update({
+            'parent': parent_obj,
+            'abs_parent_path': abs_parent_path
+        })
+
+        if not node.get('children'):
+            return
+
+        for child in node['children']:
+            self.add_parent(child, node)
+
     def add_super_by(self):
         for node in self.id_map.values():
             if not node.get('super_id'):
@@ -271,21 +290,16 @@ class DataManager:
 
         return _matched_data
 
-    def _format_respose_data(self, flow):
+    @staticmethod
+    def _format_respose_data(flow):
         # TODO render mock data before response, support more functions
         origin_response_data = flow['response']['data']
 
-        try:
-            flow['response']['data'] = utils.render_data_with_tojson(flow['response']['data'])
-        except Exception:
-            flow['response']['data'] = origin_response_data
-            logger.warning(f'Format response string to json error! {flow["request"]["url"]}')
-
         try:
             flow['response']['data'] = utils.render(flow['response']['data'])
         except Exception:
             flow['response']['data'] = origin_response_data
-            logger.warning(f'Format response data error! {flow["request"]["url"]}')
+            logger.warning(f'Format response data error! {flow["request"]["url"]}\n {traceback.format_exc()}')
 
     def _is_match_rule(self, flow, rules):
         return MatchRules.match(flow, rules)
