@@ -9,7 +9,8 @@ import datetime
 import netifaces
 import traceback
 from pathlib import Path
-from jinja2 import Template
+from jinja2 import Template, StrictUndefined
+from jinja2.exceptions import UndefinedError, TemplateSyntaxError
 from contextlib import closing
 from lyrebird.log import get_logger
 from lyrebird.application import config
@@ -132,7 +133,8 @@ def download(link, input_path):
         for chunck in resp.iter_content():
             f.write(chunck)
 
-def render_data_with_tojson(data):
+
+def handle_jinja2_tojson_by_config(data):
     config_value_tojson_key = config.get('config.value.tojsonKey')
     data_with_tojson = data
     for tojson_key in config_value_tojson_key:
@@ -150,7 +152,75 @@ def render_data_with_tojson(data):
         data_with_tojson = re.sub('("{{)'+pattern_group+'(}}")', r'{{\2 | tojson}}', data_with_tojson)
     return data_with_tojson
 
-def render(data):
+
+def handle_jinja2_keywords(data, params=None):
+    '''
+    Jinja2 will throw an exception when dealing with unexpected left brackets, but right brackets will not
+    So only left brackets need to be handled
+
+    Handle 3 kinds of unexpected left brackets:
+    1. More than 2 big brackets              `{{{ }}}` `{{# #}}` `{{% %}}`
+    2. Mismatched keyword                    `{{{` `{{#` `{{%`
+    3. Unknown arguments between {{ and }}   `{{unknown}}`
+
+    Convert unexpected brackets into presentable string in Jinja2, such as `var` -> `{{ 'var' }}`
+    The unexpected left brackets above will be convert into:
+    `{{#`          ->  `{{ '{{#' }}`
+    `{{unknown}}`  ->  `{{ '{{' }}unknown{{ '}}' }}`
+    '''
+
+    keywords_pair = {
+        '{{': '}}',
+        '{%': '%}',
+        '{#': '#}'
+    }
+
+    # split by multiple `{` followed by `{` or `#`` or `%`, such as `{{`, `{{{`, `{{{{`, `{#`, `{{#`
+    # EXAMPLE
+    # data = '{{ip}} {{ip {{{ip'
+    # item_list = ['', '{{', 'ip}} ', '{{', 'ip ', '{{{', 'ip']
+    item_list = re.split('({+[{|#|%])', data)
+    if len(item_list) == 1:
+        return data
+
+    left_pattern_index = None
+    for index, item in enumerate(item_list):
+        if index % 2:
+            # 1. Handle more than 2 big brackets
+            if (len(item) > 2) or (item not in keywords_pair):
+                item_list[index] = "{{ '%s' }}" % (item)
+            else:
+                left_pattern_index = index
+            continue
+
+        if left_pattern_index is None:
+            continue
+
+        left_pattern = item_list[left_pattern_index]
+        left_pattern_index = None
+
+        # 2. Handle mismatched keyword
+        right_pattern = keywords_pair[left_pattern]
+        if right_pattern not in item:
+            item_list[index-1] = "{{ '%s' }}" % (item_list[index-1])
+            continue
+
+        # 3. Handle unknown arguments between {{ and }}
+        if left_pattern == '{{':
+            key_n_lefted = item.split('}}', 1)
+            if len(key_n_lefted) != 2:
+                continue
+            key, _ = key_n_lefted
+            key = key.strip()
+            if [key for p in params if key.startswith(p)]:
+                continue
+            item_list[index-1] = "{{ '%s' }}" % (item_list[index-1])
+
+    after_data = ''.join(item_list)
+    return after_data
+
+
+def render(data, enable_tojson=True):
     if not isinstance(data, str):
         logger.warning(f'Format error! Expected str, found {type(data)}')
         return
@@ -163,12 +233,36 @@ def render(data):
         'now':  datetime.datetime.now()
     }
 
+    if enable_tojson:
+        data = handle_jinja2_tojson_by_config(data)
+
+    # Jinja2 doc
+    # undefined and UndefinedError https://jinja.palletsprojects.com/en/3.1.x/api/#undefined-types
+    # TemplateSyntaxError https://jinja.palletsprojects.com/en/3.1.x/api/#jinja2.TemplateSyntaxError
+
     try:
+        template_data = Template(data, keep_trailing_newline=True, undefined=StrictUndefined)
+        data = template_data.render(params)
+    except (UndefinedError, TemplateSyntaxError):
+        data = handle_jinja2_keywords(data, params)
         template_data = Template(data, keep_trailing_newline=True)
-        return template_data.render(params)
+        data = template_data.render(params)
     except Exception:
         logger.error(f'Format error!\n {traceback.format_exc()}')
 
+    return data
+
+
+def get_query_array(url):
+    # query string to array
+    # like a=1&b=2 ==> [a, 1, b, 2]
+    query_array = []
+    qs_index = url.find('?')
+    if qs_index >= 0:
+        query_string = url[qs_index+1:]
+        query_array = re.split('\\&|\\=', query_string)
+    return query_array
+
 
 class CaseInsensitiveDict(dict):
     '''
